import React, { useState } from "react";
import Link from "next/link";
import { useRouter } from "next/router";
import { AiOutlineHome, AiOutlinePieChart } from "react-icons/ai";
import { BiLogIn } from "react-icons/bi"
import { FaBars } from "react-icons/fa";

interface SidebarItem {
  path: string;
  name: string;
  icon: React.ReactNode;
}
const Sidebar: React.FC = () => {
  const [ sidebarOpen, setSidebarOpen ] = useState<boolean>(false);

  const router = useRouter();

  const handleMouseEnter = () => {
    setSidebarOpen(true);
  };
  const handleMouseLeave = () => {
    setSidebarOpen(false);
  };
  const goToLogin = () => {
    router.push("/Login");
  };
  const goToSignup = () => {
    router.push("/Signup");
  };
  const barItems: SidebarItem[] = [
    {
      path: "/",
      name: "Home",
      icon: <AiOutlineHome />,
    },
    {
      path: "/Portfolio",
      name: "Portfolio",
      icon: <AiOutlinePieChart />,
    },
  ];

  return (
    <div className="side-bar-container flex fixed z-30">
      <div
        style={{ width: sidebarOpen ? "255px" : "65px" }}
        onMouseEnter={handleMouseEnter}
        onMouseLeave={handleMouseLeave}
        className="sidebar bg-sidebar-color text-white h-screen transition-all duration-500 overflow-hidden"
      >
        <div className="flex flex-row items-center ml-2.5 mt-5 mb-3 max-h-5">
          <h1
            style={{
              display: sidebarOpen ? "block" : "none",
              animation: sidebarOpen
                ? "fadeIn 0.5s ease-in"
                : "fadeOut 0.5s ease-out",
                
            }}
            className="logo-text text-4xl p-0 fixed"
          >
            FinVis
          </h1> 
          <div
            style={{
              marginLeft: sidebarOpen ? "185px" : "-2px",
              animation: sidebarOpen
                ? "slideOut 0.38s ease-in-out"
                : "slideIn 0.3s ease-in-out",
            }}
            className="logo"
          >
            <img src="/finvis_logo.png" alt="finvis logo"/>
          </div>
        </div>
        {barItems.map((item, index) => (
          <Link
            href={item.path}
            key={index}
            className={`link ${router.pathname === item.path ? 'active' : ''}`}
            style={{ width: sidebarOpen ? "95.7%" : "84%" }}
          >
            <div className="icon">{item.icon}</div>
            <div className="link_text">{item.name}</div>
          </Link>
        ))}

          <div className="login ">
            <div className="icon">
              <BiLogIn />
            </div>
            <div
              style={{
                display: sidebarOpen ? "flex" : "none",
                animation: sidebarOpen
                  ? "fadeIn 0.8s ease-in-out"
                  : "fadeOut 0.8s ease-in-out",
              }}
              className="login-buttons"
            >
              <button onClick={goToLogin}>Log In</button>
              <button onClick={goToSignup}>Sign up</button>
            </div>
          </div>
      </div>

    </div>
  );
};
export default Sidebar;
