import React from "react";
import { PieChart, Pie, Legend, Tooltip, Cell, ResponsiveContainer } from "recharts";

type renderCustomizedLabelProps = {
  cx: number;
  cy: number;
  midAngle: number;
  innerRadius: number;
  outerRadius: number;
  percent: number;
  index: number;
};
interface BreakdownData {
  name: string;
  value: number;
}
interface PortfolioBreakDownChartProps {
  data: BreakdownData[];
}

const data01 = [
  { name: "Group A", value: 400 },
  { name: "Group B", value: 300 },
  { name: "Group C", value: 300 },
  { name: "Group D", value: 200 },
  { name: "Group C", value: 300 },
  { name: "Group D", value: 200 },
];

const COLORS = ["#0088FE", "#00C49F", "#FFBB28", "#FF8042"];

const RADIAN = Math.PI / 180;
const renderCustomizedLabel = <T extends renderCustomizedLabelProps>({
  cx,
  cy,
  midAngle,
  innerRadius,
  outerRadius,
  percent,
  index,
}: T) => {
  const radius = innerRadius + (outerRadius - innerRadius) * 0.5;
  const x = cx + radius * Math.cos(-midAngle * RADIAN);
  const y = cy + radius * Math.sin(-midAngle * RADIAN);

  return (
    <text
      x={x}
      y={y}
      fill="white"
      textAnchor={x > cx ? "start" : "end"}
      dominantBaseline="central"
      className="text-sm "
    >
      {`${(percent * 100).toFixed(0)}%`}
    </text>
  );
};
const PortfolioBreakDownChart: React.FC<PortfolioBreakDownChartProps> = ({data}) => {
  return (
    <ResponsiveContainer width="100%" height="45%" >
      <PieChart width={400} height={400} margin={{
          top: -10,
          right: 0,
          left: 0,
          bottom: -5,
        }}>
        <Pie
          dataKey="value"
          isAnimationActive={false}
          data={data}
          label={renderCustomizedLabel}
          labelLine={false}
          innerRadius={35}
          outerRadius={65}
          fill="#8884d8"
        >
          {data.map((entry, index) => (
              <Cell key={`cell-${index}`} fill={COLORS[index % COLORS.length]} />
            ))}
        </Pie>
        <Tooltip />
      </PieChart>
    </ResponsiveContainer>
  );
};
export default PortfolioBreakDownChart;
