import React from "react";
import {
  LineChart,
  Line,
  XAxis,
  YAxis,
  CartesianGrid,
  Tooltip,
  Legend,
  ResponsiveContainer,
} from "recharts";
import "chart.js/auto";

interface PortfolioValueData {
  date: string;
  value: number;
}

interface PortfolioValueChartProps {
  data1: PortfolioValueData[];
  currentPortfolioValue: number;
}

const PortfolioValueChart: React.FC<PortfolioValueChartProps> = ({
  data1,
  currentPortfolioValue,
}) => {
  return (
    <ResponsiveContainer width="100%" height="98%">
      <LineChart
        width={500}
        height={300}
        data={data1}
        margin={{
          top: 10,
          right: 15,
          left: 5,
          bottom: 5,
        }}
      >
        <CartesianGrid vertical={false} stroke="gray" />
        <XAxis
          dataKey="date"
          axisLine={false}
          tickLine={false}
          style={{ fontSize: "10px" }}
        />
        <YAxis axisLine={false} domain={[0, 5000]}  tickLine={false} style={{ fontSize: "10px" }} min={10000} />
        <Tooltip />
        <Legend />
        <Line dataKey="value" stroke="#82ca9d" />
      </LineChart>
    </ResponsiveContainer>
  );
};

export default PortfolioValueChart;
