import React from "react";
import { DataGrid, GridCellParams } from "@mui/x-data-grid";
import PortfolioCard from "./PortfolioCard";
import CardHeader from "./CardHeader";
import { Box } from "@mui/material";

interface Position {
  id: string;
  position: number;
  avgPrice: number;
  currentPrice: number;
  totalValue: number;
}
interface PositionsListCardProps {
  data: Position[];
}
const PositionsListCard: React.FC<PositionsListCardProps> = ({ data }) => {
  const positionColumns = [
    {
      field: "id",
      headerName: "Ticker",
      headerClassName: "text-white ",
      flex: .8,
    },
    {
      field: "position",
      headerName: "Positions",
      headerClassName: "text-white",
      flex: 0.5,
    },
    {
      field: "avgPrice",
      headerName: "Avg. Price",
      headerClassName: "text-white",
      flex: 0.5,
      renderCell: (params: GridCellParams) => `$${params.value}`,
    },
    {
      field: "currentPrice",
      headerName: "Current Price",
      headerClassName: "text-white",
      flex: 0.5,
      renderCell: (params: GridCellParams) => `$${params.value}`,
    },
    {
        field: "totalValue",
        headerName: "Total Value",
        headerClassName: "text-white",
        flex: 0.5,
        renderCell: (params: GridCellParams) => `$${params.value}`,
      },

  ];

  return (
    <PortfolioCard gridArea="d" className="max-h-fit bg-gray-900">
      <CardHeader
        title="Positions List"
        description="Table that displays all your positions"
        sideText={`${data?.length} Tickers`}
      />
      <Box
        sx={{
          "& .MuiDataGrid-root": { color: "#d1d3da", border: "none" },
          "& .MuiDataGrid-cell": {
            borderBottom: `1px solid "#48494e" !important`,
          },
          "& .MuiDataGrid-columnHeaders": {
            borderBottom: `1px solid "#48494e" !important`,
          },
          "& .MuiDataGrid-columnSeparator": {
            visibility: "hidden",
          },
        }}
        maxHeight="250px"
        className="mt-4 overflow-auto p-1"
      >
        <DataGrid
          rows={data || []}
          columns={positionColumns}
          columnHeaderHeight={25}
          rowHeight={35}
          hideFooter={true}
          autoHeight
          sx={{}}
        />
      </Box>
    </PortfolioCard>
  );
};

export default PositionsListCard;
