import React from "react";
import Layout from "~/components/global/Layout";

import { Box, useMediaQuery } from "@mui/material";
import CardHeader from "~/components/portfolio/CardHeader";
import PortfolioCard from "~/components/portfolio/PortfolioCard";
import MonthlyProfitsCard from "~/components/portfolio/MonthlyProfitsCard";
import PortfolioValueChart from "~/components/portfolio/PortfolioValueChart";
import PortfolioBreakDownChart from "~/components/portfolio/PortfolioBreakDownChart";
import PortfolioValueGoalChart from "~/components/portfolio/PortfolioValueGoalChart";
import PositionsListCard from "~/components/portfolio/PositionsListCard";
import RecentOrdersCard from "~/components/portfolio/RecentOrdersCard";

interface positionsTypes {
  id: string;
  position: number;
  avgPrice: number;
  currentPrice: number;
  totalValue: number;
}

const Portfolio: React.FC = () => {
  const isAboveMediumScreens = useMediaQuery("(min-width: 1200px");

  // TODO: Replace this with real data
  const InvestmentData = [
    { name: "Service", value: 1000 },
    { name: "Health", value: 1500 },
    { name: "Tech", value: 2000 },
  ];
  // Dummy data for Portfolio Value
  const portfolioValueData = [
    { date: "Day 0", value: 0 },
    { date: "Day 1", value: 2500 },
    { date: "Day 2", value: 2600 },
    { date: "Day 3", value: 2650 },
    { date: "Day 4", value: 2700 },
    { date: "Day 5", value: 2800 },
    { date: "Day 6", value: 2936 },
    { date: "Day 7", value: 3010 },
    { date: "Day 8", value: 3500 },
    { date: "Day 9", value: 3200 },
  ];
  const positionsData = [
    {
      id: "AAPL",
      position: 5,
      avgPrice: 140,
      currentPrice: 150,
      totalValue: 750,
    },
    {
      id: "MSFT",
      position: 3,
      avgPrice: 210,
      currentPrice: 220,
      totalValue: 660,
    },
    {
      id: "AMZN",
      position: 1,
      avgPrice: 3000,
      currentPrice: 3100,
      totalValue: 3100,
    },
    {
      id: "GOOG",
      position: 2,
      avgPrice: 2000,
      currentPrice: 2100,
      totalValue: 4200,
    },
    {
      id: "META",
      position: 4,
      avgPrice: 300,
      currentPrice: 320,
      totalValue: 1280,
    },
    {
      id: "TSLA",
      position: 1,
      avgPrice: 600,
      currentPrice: 700,
      totalValue: 700,
    },
    {
      id: "MSFT",
      position: 3,
      avgPrice: 210,
      currentPrice: 220,
      totalValue: 660,
    },
    {
      id: "AMZN",
      position: 1,
      avgPrice: 3000,
      currentPrice: 3100,
      totalValue: 3100,
    },
    {
      id: "GOOG",
      position: 2,
      avgPrice: 2000,
      currentPrice: 2100,
      totalValue: 4200,
    },
    {
      id: "META",
      position: 4,
      avgPrice: 300,
      currentPrice: 320,
      totalValue: 1280,
    },
    {
      id: "TSLA",
      position: 1,
      avgPrice: 600,
      currentPrice: 700,
      totalValue: 700,
    },
  ];
  const calculateTotalValue = (data: positionsTypes[]) => {
    let value = 0;
    if (data) {
      for (let i = 0; i < data.length; i++) {
        if (data[i]) {
          value += data[i].currentPrice * data[i].position;
        }
      }
    }
    return value;
  };
  const currentPortfolioValue = calculateTotalValue(positionsData);

  const gridTemplateLargeScreens = `
    "a a b"
    "a a b"
    "a a b"
    "a a b"
    "a a c"
    "d d c"
    "d d c"
    "d d c"
    "d d e"
    "f g e"
    "f g e"
    "f g e"
   
    
  `;
  const gridTemplateSmallScreens = `
    "a"
    "a"
    "a"
    "a"
    "b"
    "b"
    "b" 
    "c"
    "c"
    "c"
    "d"
    "d"
    "d"
  `;
  return (
    <Layout>
      <Box
        display="grid"
        gap="1.3rem"
        sx={
          isAboveMediumScreens
            ? {
                gridTemplateColumns: "repeat(3, minmax(370px, 1fr))",
                gridTemplateRows: "repeat(12, minmax(60px, 1fr))",
                gridTemplateAreas: gridTemplateLargeScreens,
              }
            : {
                gridAutoColumns: "1fr",
                gridAutoRows: "90px",
                gridTemplateAreas: gridTemplateSmallScreens,
              }
        }
      >
        <PortfolioCard gridArea="a" className="flex bg-gray-900">
          <div className="flex w-3/4 flex-col">
            <CardHeader
              title="Portfolio Value"
              description="graph representing your portfolio value day"
              sideText="+4%"
            />
            <PortfolioValueChart
              data1={portfolioValueData}
              currentPortfolioValue={currentPortfolioValue}
            />
          </div>
          <div className="flex w-1/4 flex-col items-center">
            <h1 className="font-jetbrains mt-5 text-2xl font-thin text-white">
              ${currentPortfolioValue}
            </h1>
            <PortfolioBreakDownChart data={InvestmentData} />
            <PortfolioValueGoalChart
              totalValue={currentPortfolioValue}
              goalValue={40000}
            />
          </div>
        </PortfolioCard>
        <MonthlyProfitsCard />
        <PortfolioCard gridArea="c" className="bg-gray-900" />
        <PositionsListCard data={positionsData} />
        <PortfolioCard gridArea="e" className="bg-gray-900" />
        <PortfolioCard gridArea="f" className="bg-gray-900" />
        <PortfolioCard gridArea="g" className="bg-gray-900" />


      </Box>
    </Layout>
  );
};

export default Portfolio;
