import { z } from "zod";
import bcrypt from "bcrypt";

import {
  createTRPCRouter,
  protectedProcedure,
  publicProcedure,
} from "~/server/api/trpc";


// Main login router for backend
export const loginRouter = createTRPCRouter({
    // Takes in username and password
  create_account: publicProcedure
    .input(z.object({email: z.string(), username: z.string(), password: z.string()}))
    .mutation(async ({ ctx, input }) => {
      // Encryption using bcrypt salt and pepper hashing
      const saltRounds = 10;
      let password_hash = "";

      bcrypt.hash(input.password, saltRounds, (err,hash) => {
        password_hash = hash;
      });
      // Store in database
      const userModelData = ctx.UserModel().create({
        username: input.username,
        password: password_hash,
        email: input.email,
      });
      // Return greeting information
        return {
        user_info: userModelData
      };
    }),

  login: publicProcedure
    .input(z.object({ username: z.string(), password: z.string(), }))
    .query(async ({ ctx, input }) => {
      // Encryption using bcrypt salt and pepper hashing
      const saltRounds = 10;
      // Get hash from database
      const password_hash = ctx.UserModel.find({username: input.username},'password');
      let is_valid = false;
      bcrypt.compare(input.password, password_hash, (err, result) => {
        // returns result
        is_valid = result;
      });
      // Return for sign in
      if(is_valid) {
        return {
          user: ctx.UserModel.find({username: input.username}),
          success: true,
        };
      }
      return {
        user: null,
        success: false,
      };
    }),
});
